##  Applications Out of Scope
The following applications are out of scope:
  * B2C SaaS applications (for example, Duolingo, Netflix, Spotify)
  * Desktop client and on-premise server applications (for example, Adobe Photoshop, Microsoft Office client applications for Windows and MacOS, Slack Desktop Client, VMWare Workstation Pro)
  * Websites, which are primarily focusing on B2C or which are solely used to provide information without functionally which allows them to be embedded in other applications (for example, Amazon, eBay, Facebook).
  * Plug-ins and add-ons for platforms (for example, browser extensions, marketplace apps, Atlassian Confluence plug-ins), except for major plug-ins and add-ons of top vendors
  * Mobile applications that are available as web-based solutions or desktop applications, such as Slack, Microsoft Outlook, or Zoom, aren’t added to the reference catalog separately.
